package com.djhk.uav.uav.mapper;




import com.djhk.uav.uav.model.UavInformation;

import java.util.List;

/**
 * 靶机库反制设备Mapper接口
 *
 * @author zhulongchuan
 * @date 2024-11-11
 */
public interface UavInformationMapper {
    /**
     * 查询靶机库反制设备
     *
     * @param UavId 靶机库反制设备主键
     * @return 靶机库反制设备
     */
    public UavInformation selectUavInformationByUavId(Long UavId);

    /**
     * 查询靶机库反制设备列表
     *
     * @param UavInformationVo 靶机库反制设备
     * @return 靶机库反制设备集合
     */
    public List<UavInformation> selectUavInformationList(UavInformation UavInformationVo);

    /**
     * 新增靶机库反制设备
     *
     * @param UavInformation 靶机库反制设备
     * @return 结果
     */
    public int insertUavInformation(UavInformation UavInformation);

    /**
     * 修改靶机库反制设备
     *
     * @param UavInformation 靶机库反制设备
     * @return 结果
     */
    public int updateUavInformation(UavInformation UavInformation);

    /**
     * 删除靶机库反制设备
     *
     * @param UavId 靶机库反制设备主键
     * @return 结果
     */
    public int deleteUavInformationByUavId(Long UavId);

    /**
     * 批量删除靶机库反制设备
     *
     * @param UavIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteUavInformationByUavIds(Long[] UavIds);
}
